@@ -588,7 +588,7 @@ static void process_menu_or_item (GtkTreeIter      *process_iter,
     If a menu that contained invisible orphaned menus is saved with the "Keep Root Menu Separate in Saved Menu File" being disabled, 
     this filter callback function renders the children of such menus visible, provided that they have a label. 
     If they don't have a label, child menus, pipe menus, and items will remain invisible and are marked as such. The same applies 
-    if a former invisible orphaned menu didn't have a label; it is now no longer orphaned, but due to the missing label it 
+    if a previously invisible orphaned menu didn't have a label; it is now no longer orphaned, but due to the missing label it 
     remains invisible.
 
 */
@@ -887,7 +887,7 @@ void save_menu (gchar *save_as_filename)
         }
 
         if (invisible_orphaned_menu_has_been_converted_to_visible) {
-            show_message_dialog (_("Former Invisible Orphaned Menus Are Now Visible"), "gtk-info", 
+            show_message_dialog (_("Previously Invisible Orphaned Menus Are Now Visible"), "gtk-info", 
                                  _("This menu contained invisible orphaned menus. Since this menu has been saved "
                                    "right now with the \"Keep Root Menu Separate in Saved Menu File\" option "
                                    "being <b>disabled</b>, these menus have become part of the root menu now and, "
